# is_windows_system
check if current system is windows.

## Install

```bash
pip install is_windows_system
```

## Usage

```python
from is_windows_system import is_windows_system

# True, False
print(is_windows_system())
```
